#!/bin/sh

###################################################################################
#   version: 6.2
#   Shell script for starting Madsonic Node service.  
#   more help at http://forum.madsonic.org
###################################################################################

NODE_HOME=/var/madsonic-node
NODE_HOST=0.0.0.0
NODE_PORT=8181
NODE_HTTPS_PORT=0
NODE_CONTEXT_PATH=/
NODE_INIT_MEMORY=128
NODE_MAX_MEMORY=256
NODE_DEFAULT_TRANSCODE_FOLDER=
NODE_DEFAULT_TIMEZONE=
NODE_PIDFILE=
NODE_GZIP=
quiet=0

usage() {
    echo "Usage: madsonic-node.sh [options]"
    echo "  --help                                This small usage guide."
    echo "  --home=DIR                            The directory where Madsonic Node will create files."
    echo "                                        Make sure it is writable. Default: /var/madsonic-node"
    echo "  --host=HOST                           The host name or IP address on which to bind ther service."
    echo "                                        Only relevant if you have multiple network interfaces and want"
    echo "                                        to make Madsonic Node available on only one of them. The default value"
    echo "                                        will bind Madsonic Node to all available network interfaces. Default: 0.0.0.0"
    echo "  --port=PORT                           The port on which Madsonic Node will listen for"
    echo "                                        incoming HTTP traffic. Default: 8181"
    echo "  --https-port=PORT                     The port on which Madsonic Node will listen for"
    echo "                                        incoming HTTPS traffic. Default: 0 (disabled)"
    echo "  --context-path=PATH                   The context path, i.e., the last part of the Madsonic Node"
    echo "                                        URL. Typically '/' or '/node'. Default '/'"
    echo "  --init-memory=MB                      The memory initial size (Init Java heap size) in megabytes." 
    echo "                                        Default: 128"
    echo "  --max-memory=MB                       The memory limit (max Java heap size) in megabytes." 
    echo "                                        Default: 256"
    echo "  --pidfile=PIDFILE                     Write PID to this file."
    echo "                                        Default not created."
    echo "  --default-transcode-folder=DIR        Configure Madsonic Node to use this folder for transcoder."
    echo "  --timezone=Zone/City                  Configure Madsonic Node to use other timezone for time correction"
    echo "                                        Example 'Europe/Vienna', 'US/Central', 'America/New_York'"
    echo "  --quiet                               Don't print anything to standard out. Default false."
    exit 1 
}

# Parse arguments.
while [ $# -ge 1 ]; do
    case $1 in
        --help)
            usage
            ;;
        --home=?*)
            NODE_HOME=${1#--home=}
            ;;
        --host=?*)
            NODE_HOST=${1#--host=}
            ;;
        --port=?*)
            NODE_PORT=${1#--port=}
            ;;
        --https-port=?*)
            NODE_HTTPS_PORT=${1#--https-port=}
            ;;
        --context-path=?*)
            NODE_CONTEXT_PATH=${1#--context-path=}
            ;;
        --init-memory=?*)
            NODE_INIT_MEMORY=${1#--init-memory=}
            ;;
        --max-memory=?*)
            NODE_MAX_MEMORY=${1#--max-memory=}
            ;;
        --pidfile=?*)
            NODE_PIDFILE=${1#--pidfile=}
            ;;
        --default-transcode-folder=?*)
            NODE_DEFAULT_TRANSCODE_FOLDER=${1#--default-transcode-folder=}
            ;;
        --timezone=?*)
           NODE_DEFAULT_TIMEZONE=${1#--timezone=}
           ;;
        --quiet)
            quiet=1
            ;;
        *)
            usage
            ;;
    esac
    shift
done

# Use JAVA_HOME if set, otherwise assume java is in the path.
JAVA=java
if [ -e "${JAVA_HOME}" ]
    then
    JAVA=${JAVA_HOME}/bin/java
fi

# Create Madsonic home directory.
mkdir -p ${NODE_HOME}
LOG=${NODE_HOME}/madsonic_node_sh.log
rm -f ${LOG}

cd $(dirname $0)
if [ -L $0 ] && ([ -e /bin/readlink ] || [ -e /usr/bin/readlink ]); then
    cd $(dirname $(readlink $0))
fi

${JAVA} -Xms${NODE_INIT_MEMORY}m \
  -Xmx${NODE_MAX_MEMORY}m \
  -Dmadsonic.home=${NODE_HOME} \
  -Dmadsonic.host=${NODE_HOST} \
  -Dmadsonic.port=${NODE_PORT} \
  -Dmadsonic.httpsPort=${NODE_HTTPS_PORT} \
  -Dmadsonic.contextPath=${NODE_CONTEXT_PATH} \
  -Dmadsonic.defaultTranscodeFolder=${NODE_DEFAULT_TRANSCODE_FOLDER} \
  -Duser.timezone=${NODE_DEFAULT_TIMEZONE} \
  -Djava.awt.headless=true \
  -jar madsonic-node-booter.jar > ${LOG} 2>&1 &

# Add this line to set audio device
#  -Djavax.sound.sampled.SourceDataLine="#ALSA" \ #
  
  
# Write pid to pidfile if it is defined.
if [ $NODE_PIDFILE ]; then
    echo $! > ${NODE_PIDFILE}
fi

if [ $quiet = 0 ]; then
    echo Started Madsonic-Node [PID $!, ${LOG}]
fi
